@@ -16,9 +16,11 @@ use std::io::Read;
 use crate::pkg::CustomError;
 
 // todo: global use varible here
-pub const PKGX: pkg::Pkg = pkg::Pkg::new(true);
+// pub const PKGX: pkg::Pkg = pkg::Pkg::new(true);
 
 pub struct Client {
+  pub debug: bool,
+
   host: String,
   port: u16,
 
@@ -29,6 +31,7 @@ pub struct Client {
 impl Client {
   pub fn new<S: Into<String>>(host: S, port: u16) -> Client {
     Client {
+      debug: false,
       host: host.into(),
       port: port,
       kv: KVPair::new(),
@@ -36,6 +39,12 @@ impl Client {
     }
   }
 
+  pub fn debug_print(&self, s: &str) {
+    if self.debug {
+      println!("[DEBUG] --- {:?}", s);
+    }
+  }
+
   pub fn kv_get<S: Into<String>>(&self, key: S) -> Result<Vec<KVPair>, String> {
     self.kv.get(self, key)
   }
@@ -57,10 +66,17 @@ impl Client {
                      behavior: String, ttl: String) -> String {
     let mut s = session::Session::new();
     s.lock_delay = lock_delay;
-    s.name = name;
-    s.node = node;
+    if name != "".to_string() {
+      s.name = name;
+    }
+
+    if node != "".to_string() {
+      let nodex = Some(node);
+      s.node = nodex;
+    }
     s.behavior = behavior;
     s.ttl = ttl;
+    self.debug_print(format!("lib session set: {:?}", s).as_str());
     self.session.set(self, &s)
   }
 
